Extract the approximated spatial correlation between one coordinate and other coordinates using a sparse precision and SPDE mesh
spatial_cor(Q, mesh, coord, pred)A vector with length nrow(pred) giving the spatial correlation
sparse precision matrix
SPDE mesh
vector of length-2 with spatial coordinates for focal point
matrix with two columns and multiple rows, with location for points to predict correlation