| tinyVASTcontrol | R Documentation |
Control parameters for tinyVAST
tinyVASTcontrol(
opt_loops = 1,
newton_loops = 0,
eval.max = 10000,
iter.max = 10000,
getsd = TRUE,
silent = getOption("tinyVAST.silent", TRUE),
trace = getOption("tinyVAST.trace", 0),
verbose = getOption("tinyVAST.verbose", FALSE),
profile = c(),
tmb_par = NULL,
tmb_map = NULL,
tmb_random = NULL,
gmrf_parameterization = c("separable", "projection"),
reml = FALSE,
getJointPrecision = FALSE,
calculate_deviance_explained = TRUE,
run_model = TRUE,
suppress_user_warnings = FALSE,
get_rsr = FALSE,
extra_reporting = FALSE,
use_anisotropy = FALSE,
sar_adjacency = "queen",
barrier_stiffness = 0.01
)
opt_loops |
Integer number of times to call nonlinear optimizer. |
newton_loops |
Integer number of Newton steps to do after running
|
eval.max |
Maximum number of evaluations of the objective function
allowed. Passed to |
iter.max |
Maximum number of iterations allowed. Passed to |
getsd |
Boolean indicating whether to call |
silent |
Disable terminal output for inner optimizer? |
trace |
Parameter values are printed every |
verbose |
Output additional messages about model steps during fitting? |
profile |
Character-vector passed to TMB::MakeADFun and see description
there. Fixed effects that are highly correlated with random effects
can often be estimated faster (i.e., with fewer iterations) by adding
them to |
tmb_par |
named list of parameters used as starting values. Elements that
have names that match those constructed internally then replace the
internally constructed starting values. Those that match must have identical
shape to |
tmb_map |
input passed to TMB::MakeADFun as argument |
tmb_random |
input passed to TMB::MakeADFun as argument |
gmrf_parameterization |
Parameterization to use for the Gaussian Markov
random field, where the default |
reml |
Logical: use REML (restricted maximum likelihood) estimation rather than maximum likelihood? Internally, this adds the fixed effects to the list of random effects to integrate over. |
getJointPrecision |
whether to get the joint precision matrix. Passed
to |
calculate_deviance_explained |
whether to calculate proportion of deviance
explained. See |
run_model |
whether to run the model of export TMB objects prior to compilation (useful for debugging) |
suppress_user_warnings |
whether to suppress warnings from package author regarding dangerous or non-standard options |
get_rsr |
Experimental option, whether to report restricted spatial regression (RSR) adjusted estimator for covariate responses |
extra_reporting |
Whether to report a much larger set of quantities via
|
use_anisotropy |
Whether to estimate two parameters representing geometric anisotropy |
sar_adjacency |
Whether to use queen or rook adjacency when defining a Simultaneous Autoregressive spatial precision from a sfc_GEOMETRY (default is queen) |
barrier_stiffness |
The ratio of local stiffness (the scale of diffusion
rate and resulting decorrelation distance) for barriers relative to normal areas
in the SPDE method when using |
An object (list) of class tinyVASTcontrol, containing either default or
updated values supplied by the user for model settings
Bakka, H., Vanhatalo, J., Illian, J., Simpson, D., Rue, H. (2019). Non-stationary Gaussian models with physical barriers. Spatial Statistics, 29, 268-288. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.spasta.2019.01.002")}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.