Make a RAM (Reticular Action Model) from a SEM (structural equation model)
Source:R/make_sem_ram.R
make_sem_ram.Rdmake_sem_ram converts SEM arrow notation to ram describing SEM parameters
Arguments
- sem
structural equation model structure, passed to either
specifyModelorspecifyEquationsand then parsed to control the set of path coefficients and variance-covariance parameters- variables
A character vector listing the set of variables
- quiet
Boolean indicating whether to print messages to terminal
- covs
A character vector listing variables for which to estimate a standard deviation